# RemotiveTopology framework

RemotiveTopology framework is a python library that allows you to easily interact with RemotiveTopology. Using the framework you can create Behavioral Models or write test cases probing communication channels.

## Installation

```bash
pip install remotivelabs-topology
```

## Project Links

- [Documentation](https://docs.remotivelabs.com/apis/python/remotivelabs/topology)
- [Examples](https://github.com/remotivelabs/remotivelabs-topology-examples)
- [Issues](mailto:support@remotivelabs.com)
